###########################################################################################
## Code used in "Relatedness within and between Agta residential groups"
## Dyble, Migliano, Page, Smith (2021)
##########################################################################################

#### Import the data; there are four .csv files to import:
# ind_data
# spouses
# group_pairwise
# camps

library(ppcor); library(ggplot2)

### Subset data for adults and children
adults <- ind_data[which(ind_data$Age_cat=="ADULT"),]
children <- ind_data[which(ind_data$Age_cat=="CHILD"),]

##### RESULTS PARAGRAPH 1

## Relatedness to all adults in population
round(mean(adults$r_to_all_adults),3)
round(sd(adults$r_to_all_adults),3)

## Relatedness to campmates?
round(mean(adults$r_to_adults),3)
round(sd(adults$r_to_adults),3)

## Adults camp size?
mean(camps$camp_adult_men+camps$camp_adult_women)
sd(camps$camp_adult_men+camps$camp_adult_women)

### Corr w/ group size
cor.test(camps$camp_all_r,camps$camp_total)

### Relatedness among all campmates?
round(mean(ind_data$r_to_adults),3)
round(sd(ind_data$r_to_adults),3)

### Relatedness adults to children
round(mean(adults$r_to_children),3)
round(sd(adults$r_to_children),3)
length(adults$r_to_children)

### relatedness children to children?
round(mean(children$r_to_children),3)
round(sd(children$r_to_children),3)
length(children$r_to_children)



### RESULTS PARAGRAPH 2

## adult to adult shared reproductive interest?
## whole popn:
round(mean(adults$s_to_all_adults),3)
round(sd(adults$s_to_all_adults),3)

## in camp:
round(mean(adults$s_to_adults),3)
round(sd(adults$s_to_adults),3)


##### RESULTS PARAGRAPH 3

cor.test(camps$turnover,camps$camp_all_r,na.rm=T)
y.data <- data.frame(rel = camps$camp_all_r,siz = camps$camp_total,stability = camps$turnover)
y.data <- y.data[which(!is.na(y.data$stability)),]
pcor(y.data)

cor.test(camps$forage,camps$camp_all_r,na.rm=T)
y.data <- data.frame(rel = camps$camp_all_r,siz = camps$camp_total,forage = camps$forage)
y.data <- y.data[which(!is.na(y.data$forage)),]
pcor(y.data)


#### RESULTS PARAGRAPH 4

## Sex difference in adults relatedness to other adults?
round(mean(adults$r_to_adults[which(adults$Sex=="M")]),3)
round(sd(adults$r_to_adults[which(adults$Sex=="M")]),3)
length(adults$r_to_adults[which(adults$Sex=="M")])

round(mean(adults$r_to_adults[which(adults$Sex=="F")]),3)
round(sd(adults$r_to_adults[which(adults$Sex=="F")]),3)
length(adults$r_to_adults[which(adults$Sex=="F")])

## Permutation test
set.seed(17062021) # set to today's date
obs_diff <- mean(adults$r_to_adults[which(adults$Sex=="M")]) - mean(adults$r_to_adults[which(adults$Sex=="F")])
sims <- 1000 ;sim_diff <- 1:1000
for(i in 1:sims){
  temp <- sample(adults$Sex)
  sim_diff[i] <-  mean(adults$r_to_adults[which(temp=="M")]) - mean(adults$r_to_adults[which(temp=="F")]) 
}
length(which(abs(sim_diff)>abs(obs_diff)))/1000


## Sex difference in adults 's' to other adults?
round(mean(adults$s_to_adults[which(adults$Sex=="M")]),3)
round(sd(adults$s_to_adults[which(adults$Sex=="M")]),3)
length(adults$s_to_adults[which(adults$Sex=="M")])

round(mean(adults$s_to_adults[which(adults$Sex=="F")]),3)
round(sd(adults$s_to_adults[which(adults$Sex=="F")]),3)
length(adults$s_to_adults[which(adults$Sex=="F")])

## Permutation test
set.seed(17062021) # set to today's date
obs_diff <- mean(adults$s_to_adults[which(adults$Sex=="M")]) - mean(adults$s_to_adults[which(adults$Sex=="F")])
sims <- 1000; sim_diff <- 1:1000
for(i in 1:sims){
  temp <- sample(adults$Sex)
  sim_diff[i] <-  mean(adults$s_to_adults[which(temp=="M")]) - mean(adults$s_to_adults[which(temp=="F")]) 
}
length(which(abs(sim_diff)>abs(obs_diff)))/1000



#### RESULTS PARAGRAPH  5

### distance and relatedness
cor.test(group_pairwise$distances,group_pairwise$rs,method = 'spearman')

#### camps with kin?
mean(adults$N_camps_w_kin)
sd(adults$N_camps_w_kin)
min(adults$N_camps_w_kin)
max(adults$N_camps_w_kin)

## sex difference in N camps with kin?
mean(adults$N_camps_w_kin[which(adults$Sex=="M")])
sd(adults$N_camps_w_kin[which(adults$Sex=="M")])
length(adults$N_camps_w_kin[which(adults$Sex=="M")])

mean(adults$N_camps_w_kin[which(adults$Sex=="F")])
sd(adults$N_camps_w_kin[which(adults$Sex=="F")])
length(adults$N_camps_w_kin[which(adults$Sex=="F")])

set.seed(17062021) # set to today's date
diff <- mean(adults$N_camps_w_kin[which(adults$Sex=="M")]) - mean(adults$N_camps_w_kin[which(adults$Sex=="F")])
sim_res <- rep(NA,times=10000)
for(i in 1:10000){
  temp <- sample(adults$N_camps_w_kin)
  sim_res[i] <- mean(temp[which(adults$Sex=="M")]) - mean(temp[which(adults$Sex=="F")])
}
length(which(sim_res>=abs(diff)))/10000

#### N camps when including affines?
mean(adults$N_camps_w_con_or_aff_kin,na.rm=T)
sd(adults$N_camps_w_con_or_aff_kin,na.rm=T)
min(adults$N_camps_w_con_or_aff_kin,na.rm=T)
max(adults$N_camps_w_con_or_aff_kin,na.rm=T)




## RESULTS PARAGRAPH 6

## r between spouses?
table(spouses$relatedness)

## age between spouses?
mean(spouses$age_diff,na.rm=T)
sd(spouses$age_diff,na.rm=T)
min(spouses$age_diff,na.rm=T)
max(spouses$age_diff,na.rm=T)

length(which(spouses$age_diff>0))
length(which(spouses$age_diff>0))/length(which(!is.na(spouses$age_diff)))
length(which(spouses$age_diff<0))
length(which(spouses$age_diff<0))/length(which(!is.na(spouses$age_diff)))



####################
##### Plots
####################

## Figure 1
par(mar = c(5, 5, 2, 2))
## Fig 1a
hist(adults$r_to_adults,main="",padj=-0.5,ylab="Freq",xlab="Relatedess to group",xlim=c(0,0.3),ylim=c(0,80))
## Fig 1b
hist(ind_data$r_to_group,main="",padj=-0.5,ylab="Freq",xlab="Relatedess to group",xlim=c(0,0.3),ylim=c(0,100))
## Fig 1e
plot(camps$camp_total,camps$camp_all_r,ylab="Group relatedness", xlab="Group size (adults)",ylim=c(0,0.2),xlim=c(0,100))
## Fig 1f
boxplot(adults$r_to_adults~adults$Sex,ylim=c(0,0.25),xlab="",ylab="r to adults")


### Figure 2a
scatter1 <- ggplot(ind_data, aes(Age,r_to_group, colour= factor(Sex), fill=factor(Sex))) + geom_point(aes(shape = factor(Sex)),alpha=0.5)
scatter1 <- scatter1 +
  guides(fill=FALSE) + # gets rid of the legend
  theme_bw(13) + 
  geom_smooth(se = T, size=1, aes(linetype = factor(Sex))) +
  scale_color_manual(values = c("black","black")) + 
  ylab("Relatedness (r)") + xlab("Age") +
  scale_linetype_manual(values=c("solid", "longdash"))+
  guides(fill=F) + xlim(c(0,80)) + scale_shape_manual(values=c(1,2)) +
  scale_fill_manual(values = c("grey","grey")) + ylim(c(0,0.25)) + 
  theme(plot.margin = unit(c(0.3, 0.3, 0.3, 0.3), "cm")) + #top, right, bottom, left  
  theme(axis.title.y = element_text(vjust=1.7),legend.position="none",axis.title.x = element_text(vjust=-0.4),
        axis.ticks.length=unit(c(0.25),'cm'),axis.line = element_line(colour = "black"),
        panel.border = element_rect(colour = "white", fill=NA, size=1),panel.grid.major = element_blank(),  # get rid of the grid lines
        panel.grid.minor = element_blank()) 
print(scatter1) 


### Figure 2b
library(ggplot2)
scatter1 <- ggplot(ind_data, aes(Age,s_to_group, colour= factor(Sex), fill=factor(Sex))) + geom_point(aes(shape = factor(Sex)),alpha=0.5)
scatter1 <- scatter1 +
  guides(fill=FALSE) + # gets rid of the legend
  theme_bw(13) + geom_smooth(se = T, size=1, aes(linetype = factor(Sex))) +
  scale_color_manual(values = c("black","black")) + 
  ylab("Shared reproductive interest (s)") + xlab("Age") +
  scale_linetype_manual(values=c("solid", "longdash"))+
  guides(fill=F) + xlim(c(0,80)) + scale_shape_manual(values=c(1,2)) +
  scale_fill_manual(values = c("grey","grey")) + ylim(c(0,0.25)) + 
  theme(plot.margin = unit(c(0.3, 0.3, 0.3, 0.3), "cm")) + #top, right, bottom, left  
  theme(axis.title.y = element_text(vjust=1.7),legend.position="none",axis.title.x = element_text(vjust=-0.4),
        axis.ticks.length=unit(c(0.25),'cm'),axis.line = element_line(colour = "black"),
        panel.border = element_rect(colour = "white", fill=NA, size=1),panel.grid.major = element_blank(),  # get rid of the grid lines
        panel.grid.minor = element_blank()) 
print(scatter1) 


## Figure 2c
ads <- ind_data[which(ind_data$Age>18),]
library(ggplot2)
scatter1 <- ggplot(ads, aes(Age,r_to_adults, colour= factor(Sex), fill=factor(Sex))) + geom_point(aes(shape = factor(Sex)),alpha=0.5)
scatter1 <- scatter1 +
  guides(fill=FALSE) + # gets rid of the legend
  theme_bw(13) + geom_smooth(se = T, size=1, aes(linetype = factor(Sex))) +
  scale_color_manual(values = c("black","black")) + 
  ylab("Relatedness (r)") + xlab("Age") +
  scale_linetype_manual(values=c("solid", "longdash"))+
  guides(fill=F) + xlim(c(18,80)) + scale_shape_manual(values=c(1,2)) +
  scale_fill_manual(values = c("grey","grey")) + ylim(c(0,0.25)) + 
  theme(plot.margin = unit(c(0.3, 0.3, 0.3, 0.3), "cm")) + #top, right, bottom, left  
  theme(axis.title.y = element_text(vjust=1.7),legend.position="none",axis.title.x = element_text(vjust=-0.4),
        axis.ticks.length=unit(c(0.25),'cm'),axis.line = element_line(colour = "black"),
        panel.border = element_rect(colour = "white", fill=NA, size=1),panel.grid.major = element_blank(),  # get rid of the grid lines
        panel.grid.minor = element_blank()) 
print(scatter1) 


## Figure 2d
ads <- ind_data[which(ind_data$Age>18),]
scatter1 <- ggplot(ads, aes(Age,s_to_adults, colour= factor(Sex), fill=factor(Sex))) + geom_point(aes(shape = factor(Sex)),alpha=0.5)
scatter1 <- scatter1 +
  guides(fill=FALSE) + # gets rid of the legend
  theme_bw(13) + geom_smooth(se = T, size=1, aes(linetype = factor(Sex))) +
  scale_color_manual(values = c("black","black")) + 
  ylab("Shared reproductive interest (s)") + xlab("Age") +
  scale_linetype_manual(values=c("solid", "longdash"))+
  guides(fill=F) + xlim(c(18,80)) + scale_shape_manual(values=c(1,2)) +
  scale_fill_manual(values = c("grey","grey")) + ylim(c(0,0.25)) + 
  theme(plot.margin = unit(c(0.3, 0.3, 0.3, 0.3), "cm")) + #top, right, bottom, left  
  theme(axis.title.y = element_text(vjust=1.7),legend.position="none",axis.title.x = element_text(vjust=-0.4),
        axis.ticks.length=unit(c(0.25),'cm'),axis.line = element_line(colour = "black"),
        panel.border = element_rect(colour = "white", fill=NA, size=1),panel.grid.major = element_blank(),  # get rid of the grid lines
        panel.grid.minor = element_blank()) 
print(scatter1) 

